import 'researchEdition.m.dart';
import 'notification.m.dart';

import 'package:fis_jsonrpc/utils.dart';

class CreateFacturyPostHistoryRequest extends TokenRequest{
	String? facturyUniqueCode;
	String? facturyUrl;
	String? iDCardNo;
	String? patientName;
	String? apiType;
	int status;
	DateTime? postTime;
	Map<String,String>? headers;
	String? content;
	String? result;

	CreateFacturyPostHistoryRequest({
		this.facturyUniqueCode,
		this.facturyUrl,
		this.iDCardNo,
		this.patientName,
		this.apiType,
		this.status = 0,
		this.postTime,
		this.headers,
		this.content,
		this.result,
		String? token,
	}) : super(
			token: token,
		);

	factory CreateFacturyPostHistoryRequest.fromJson(Map<String, dynamic> map) {
		return CreateFacturyPostHistoryRequest( 
			facturyUniqueCode: map['FacturyUniqueCode'],
			facturyUrl: map['FacturyUrl'],
			iDCardNo: map['IDCardNo'],
			patientName: map['PatientName'],
			apiType: map['ApiType'],
			status: map['Status'],
			postTime: map['PostTime'] != null ? DateTime.parse(map['PostTime']) : null,
			headers: map['Headers']?.cast<String,String>(),
			content: map['Content'],
			result: map['Result'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (facturyUniqueCode != null)
			map['FacturyUniqueCode'] = facturyUniqueCode;
		if (facturyUrl != null)
			map['FacturyUrl'] = facturyUrl;
		if (iDCardNo != null)
			map['IDCardNo'] = iDCardNo;
		if (patientName != null)
			map['PatientName'] = patientName;
		if (apiType != null)
			map['ApiType'] = apiType;
		map['Status'] = status;
		if (postTime != null)
			map['PostTime'] = JsonRpcUtils.dateFormat(postTime!);
		if (headers != null)
			map['Headers'] = headers;
		if (content != null)
			map['Content'] = content;
		if (result != null)
			map['Result'] = result;
		return map;
	}
}

class FacturyPostHistoryDTO extends BaseDTO{
	String? code;
	String? facturyUniqueCode;
	String? facturyUrl;
	String? iDCardNo;
	String? patientName;
	String? apiType;
	int status;
	DateTime? postTime;
	Map<String,String>? headers;
	String? content;
	String? result;

	FacturyPostHistoryDTO({
		this.code,
		this.facturyUniqueCode,
		this.facturyUrl,
		this.iDCardNo,
		this.patientName,
		this.apiType,
		this.status = 0,
		this.postTime,
		this.headers,
		this.content,
		this.result,
		bool isDelete = false,
		DateTime? createTime,
		DateTime? updateTime,
	}) : super(
			isDelete: isDelete,
			createTime: createTime,
			updateTime: updateTime,
		);

	factory FacturyPostHistoryDTO.fromJson(Map<String, dynamic> map) {
		return FacturyPostHistoryDTO( 
			code: map['Code'],
			facturyUniqueCode: map['FacturyUniqueCode'],
			facturyUrl: map['FacturyUrl'],
			iDCardNo: map['IDCardNo'],
			patientName: map['PatientName'],
			apiType: map['ApiType'],
			status: map['Status'],
			postTime: map['PostTime'] != null ? DateTime.parse(map['PostTime']) : null,
			headers: map['Headers']?.cast<String,String>(),
			content: map['Content'],
			result: map['Result'],
			isDelete: map['IsDelete'],
			createTime: map['CreateTime'] != null ? DateTime.parse(map['CreateTime']) : null,
			updateTime: map['UpdateTime'] != null ? DateTime.parse(map['UpdateTime']) : null,
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (code != null)
			map['Code'] = code;
		if (facturyUniqueCode != null)
			map['FacturyUniqueCode'] = facturyUniqueCode;
		if (facturyUrl != null)
			map['FacturyUrl'] = facturyUrl;
		if (iDCardNo != null)
			map['IDCardNo'] = iDCardNo;
		if (patientName != null)
			map['PatientName'] = patientName;
		if (apiType != null)
			map['ApiType'] = apiType;
		map['Status'] = status;
		if (postTime != null)
			map['PostTime'] = JsonRpcUtils.dateFormat(postTime!);
		if (headers != null)
			map['Headers'] = headers;
		if (content != null)
			map['Content'] = content;
		if (result != null)
			map['Result'] = result;
		return map;
	}
}

class GetFacturyPostHistoryRequest extends TokenRequest{
	String? code;

	GetFacturyPostHistoryRequest({
		this.code,
		String? token,
	}) : super(
			token: token,
		);

	factory GetFacturyPostHistoryRequest.fromJson(Map<String, dynamic> map) {
		return GetFacturyPostHistoryRequest( 
			code: map['Code'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (code != null)
			map['Code'] = code;
		return map;
	}
}

class GetFacturyPostHistoryByPageRequest extends PageRequest{
	String? keyword;
	int status;
	DateTime? startTime;
	DateTime? endTime;

	GetFacturyPostHistoryByPageRequest({
		this.keyword,
		this.status = 0,
		this.startTime,
		this.endTime,
		int pageIndex = 0,
		int pageSize = 0,
		String? token,
	}) : super(
			pageIndex: pageIndex,
			pageSize: pageSize,
			token: token,
		);

	factory GetFacturyPostHistoryByPageRequest.fromJson(Map<String, dynamic> map) {
		return GetFacturyPostHistoryByPageRequest( 
			keyword: map['Keyword'],
			status: map['Status'],
			startTime: map['StartTime'] != null ? DateTime.parse(map['StartTime']) : null,
			endTime: map['EndTime'] != null ? DateTime.parse(map['EndTime']) : null,
			pageIndex: map['PageIndex'],
			pageSize: map['PageSize'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (keyword != null)
			map['Keyword'] = keyword;
		map['Status'] = status;
		if (startTime != null)
			map['StartTime'] = JsonRpcUtils.dateFormat(startTime!);
		if (endTime != null)
			map['EndTime'] = JsonRpcUtils.dateFormat(endTime!);
		return map;
	}
}

class RemoveFacturyPostHistoryRequest extends TokenRequest{
	String? code;

	RemoveFacturyPostHistoryRequest({
		this.code,
		String? token,
	}) : super(
			token: token,
		);

	factory RemoveFacturyPostHistoryRequest.fromJson(Map<String, dynamic> map) {
		return RemoveFacturyPostHistoryRequest( 
			code: map['Code'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (code != null)
			map['Code'] = code;
		return map;
	}
}

class ResendFacturyPostHistoryRequest extends TokenRequest{
	String? code;

	ResendFacturyPostHistoryRequest({
		this.code,
		String? token,
	}) : super(
			token: token,
		);

	factory ResendFacturyPostHistoryRequest.fromJson(Map<String, dynamic> map) {
		return ResendFacturyPostHistoryRequest( 
			code: map['Code'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (code != null)
			map['Code'] = code;
		return map;
	}
}

class CreateJingQiExamPostHistoryRequest extends TokenRequest{
	String? physicalExamNumber;
	String? examKey;
	Map<String,String>? examData;
	DateTime? examTime;

	CreateJingQiExamPostHistoryRequest({
		this.physicalExamNumber,
		this.examKey,
		this.examData,
		this.examTime,
		String? token,
	}) : super(
			token: token,
		);

	factory CreateJingQiExamPostHistoryRequest.fromJson(Map<String, dynamic> map) {
		return CreateJingQiExamPostHistoryRequest( 
			physicalExamNumber: map['PhysicalExamNumber'],
			examKey: map['ExamKey'],
			examData: map['ExamData']?.cast<String,String>(),
			examTime: map['ExamTime'] != null ? DateTime.parse(map['ExamTime']) : null,
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (physicalExamNumber != null)
			map['PhysicalExamNumber'] = physicalExamNumber;
		if (examKey != null)
			map['ExamKey'] = examKey;
		if (examData != null)
			map['ExamData'] = examData;
		if (examTime != null)
			map['ExamTime'] = JsonRpcUtils.dateFormat(examTime!);
		return map;
	}
}

class CreateJingQiReportPostHistoryRequest extends TokenRequest{
	String? reportCode;

	CreateJingQiReportPostHistoryRequest({
		this.reportCode,
		String? token,
	}) : super(
			token: token,
		);

	factory CreateJingQiReportPostHistoryRequest.fromJson(Map<String, dynamic> map) {
		return CreateJingQiReportPostHistoryRequest( 
			reportCode: map['ReportCode'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (reportCode != null)
			map['ReportCode'] = reportCode;
		return map;
	}
}


