import 'dart:core';

import 'package:fis_jsonrpc/client_base.dart';
import 'package:fis_common/json_convert.dart';

import 'vitalFacturyUser.m.dart';

import 'researchEdition.m.dart';


class VitalFacturyUserService extends JsonRpcClientBase {
	VitalFacturyUserService(
		String host, {
		String serviceName = "IVitalFacturyUserService",
		Map<String, String>? headers,
		int? timeout,
	}) : super(
						host,
						serviceName,
						headers: headers,
						timeout: timeout,
				) {
		/// 注册响应实体反序列化处理器
		FJsonConvert.setDecoder((map) => FacturyUserDTO.fromJson(map));
		FJsonConvert.setDecoder((map) => PageCollection<FacturyUserDTO>.fromJson(map));
		FJsonConvert.setDecoder((map) => FacturyExamRegisterResult.fromJson(map));
		FJsonConvert.setDecoder((map) => FacturyExamDeleteResult.fromJson(map));
	}

	Future<String> createFacturyUserAsync(CreateFacturyUserRequest request) async {
		var rpcRst = await call("CreateFacturyUserAsync", request);
		return rpcRst;
	}

	Future<bool> updateFacturyUserAsync(UpdateFacturyUserRequest request) async {
		var rpcRst = await call("UpdateFacturyUserAsync", request);
		return rpcRst;
	}

	Future<FacturyUserDTO> getFacturyUserAsync(GetFacturyUserRequest request) async {
		var rpcRst = await call("GetFacturyUserAsync", request);
		var result = FacturyUserDTO.fromJson(rpcRst as Map<String, dynamic>);
		return result;
	}

	Future<PageCollection<FacturyUserDTO>> getFacturyOrgByPageAsync(GetFacturyOrgByPageRequest request) async {
		var rpcRst = await call("GetFacturyOrgByPageAsync", request);
		var result = PageCollection<FacturyUserDTO>.fromJson(rpcRst as Map<String, dynamic>);
		return result;
	}

	Future<PageCollection<FacturyUserDTO>> getFacturyUserByPageAsync(GetFacturyUserByPageRequest request) async {
		var rpcRst = await call("GetFacturyUserByPageAsync", request);
		var result = PageCollection<FacturyUserDTO>.fromJson(rpcRst as Map<String, dynamic>);
		return result;
	}

	Future<List<FacturyUserDTO>> getFacturyUserInfosAsync(GetFacturyUserInfosRequest request) async {
		var rpcRst = await call("GetFacturyUserInfosAsync", request);
		var result = (rpcRst as List).map((e)=>FacturyUserDTO.fromJson(e as Map<String, dynamic>)).toList();
		return result;
	}

	Future<bool> removeFacturyUserAsync(RemoveFacturyUserRequest request) async {
		var rpcRst = await call("RemoveFacturyUserAsync", request);
		return rpcRst;
	}

	Future<FacturyExamRegisterResult> facturyExamRegisterAsync(FacturyExamRegisterRequest request) async {
		var rpcRst = await call("FacturyExamRegisterAsync", request);
		var result = FacturyExamRegisterResult.fromJson(rpcRst as Map<String, dynamic>);
		return result;
	}

	Future<FacturyExamDeleteResult> facturyExamDeleteAsync(FacturyExamDeleteRequest request) async {
		var rpcRst = await call("FacturyExamDeleteAsync", request);
		var result = FacturyExamDeleteResult.fromJson(rpcRst as Map<String, dynamic>);
		return result;
	}

}

