import 'researchEdition.m.dart';
import 'notification.m.dart';

import 'package:fis_jsonrpc/utils.dart';

class CreateFacturyUserRequest extends TokenRequest{
	String? facturyUniqueCode;
	int facturyType;
	String? facturyCode;
	String? facturyName;
	String? fatherCode;
	Map<String,String>? facturyData;

	CreateFacturyUserRequest({
		this.facturyUniqueCode,
		this.facturyType = 0,
		this.facturyCode,
		this.facturyName,
		this.fatherCode,
		this.facturyData,
		String? token,
	}) : super(
			token: token,
		);

	factory CreateFacturyUserRequest.fromJson(Map<String, dynamic> map) {
		return CreateFacturyUserRequest( 
			facturyUniqueCode: map['FacturyUniqueCode'],
			facturyType: map['FacturyType'],
			facturyCode: map['FacturyCode'],
			facturyName: map['FacturyName'],
			fatherCode: map['FatherCode'],
			facturyData: map['FacturyData']?.cast<String,String>(),
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (facturyUniqueCode != null)
			map['FacturyUniqueCode'] = facturyUniqueCode;
		map['FacturyType'] = facturyType;
		if (facturyCode != null)
			map['FacturyCode'] = facturyCode;
		if (facturyName != null)
			map['FacturyName'] = facturyName;
		if (fatherCode != null)
			map['FatherCode'] = fatherCode;
		if (facturyData != null)
			map['FacturyData'] = facturyData;
		return map;
	}
}

class UpdateFacturyUserRequest extends TokenRequest{
	String? code;
	String? facturyUniqueCode;
	int facturyType;
	String? facturyCode;
	String? facturyName;
	String? fatherCode;
	Map<String,String>? facturyData;

	UpdateFacturyUserRequest({
		this.code,
		this.facturyUniqueCode,
		this.facturyType = 0,
		this.facturyCode,
		this.facturyName,
		this.fatherCode,
		this.facturyData,
		String? token,
	}) : super(
			token: token,
		);

	factory UpdateFacturyUserRequest.fromJson(Map<String, dynamic> map) {
		return UpdateFacturyUserRequest( 
			code: map['Code'],
			facturyUniqueCode: map['FacturyUniqueCode'],
			facturyType: map['FacturyType'],
			facturyCode: map['FacturyCode'],
			facturyName: map['FacturyName'],
			fatherCode: map['FatherCode'],
			facturyData: map['FacturyData']?.cast<String,String>(),
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (code != null)
			map['Code'] = code;
		if (facturyUniqueCode != null)
			map['FacturyUniqueCode'] = facturyUniqueCode;
		map['FacturyType'] = facturyType;
		if (facturyCode != null)
			map['FacturyCode'] = facturyCode;
		if (facturyName != null)
			map['FacturyName'] = facturyName;
		if (fatherCode != null)
			map['FatherCode'] = fatherCode;
		if (facturyData != null)
			map['FacturyData'] = facturyData;
		return map;
	}
}

class FacturyUserDTO extends BaseDTO{
	String? code;
	String? facturyUniqueCode;
	int facturyType;
	String? facturyCode;
	String? facturyName;
	String? fatherCode;
	Map<String,String>? facturyData;

	FacturyUserDTO({
		this.code,
		this.facturyUniqueCode,
		this.facturyType = 0,
		this.facturyCode,
		this.facturyName,
		this.fatherCode,
		this.facturyData,
		bool isDelete = false,
		DateTime? createTime,
		DateTime? updateTime,
	}) : super(
			isDelete: isDelete,
			createTime: createTime,
			updateTime: updateTime,
		);

	factory FacturyUserDTO.fromJson(Map<String, dynamic> map) {
		return FacturyUserDTO( 
			code: map['Code'],
			facturyUniqueCode: map['FacturyUniqueCode'],
			facturyType: map['FacturyType'],
			facturyCode: map['FacturyCode'],
			facturyName: map['FacturyName'],
			fatherCode: map['FatherCode'],
			facturyData: map['FacturyData']?.cast<String,String>(),
			isDelete: map['IsDelete'],
			createTime: map['CreateTime'] != null ? DateTime.parse(map['CreateTime']) : null,
			updateTime: map['UpdateTime'] != null ? DateTime.parse(map['UpdateTime']) : null,
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (code != null)
			map['Code'] = code;
		if (facturyUniqueCode != null)
			map['FacturyUniqueCode'] = facturyUniqueCode;
		map['FacturyType'] = facturyType;
		if (facturyCode != null)
			map['FacturyCode'] = facturyCode;
		if (facturyName != null)
			map['FacturyName'] = facturyName;
		if (fatherCode != null)
			map['FatherCode'] = fatherCode;
		if (facturyData != null)
			map['FacturyData'] = facturyData;
		return map;
	}
}

class GetFacturyUserRequest extends TokenRequest{
	String? code;

	GetFacturyUserRequest({
		this.code,
		String? token,
	}) : super(
			token: token,
		);

	factory GetFacturyUserRequest.fromJson(Map<String, dynamic> map) {
		return GetFacturyUserRequest( 
			code: map['Code'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (code != null)
			map['Code'] = code;
		return map;
	}
}

class GetFacturyOrgByPageRequest extends PageRequest{
	String? keyword;
	DateTime? startTime;
	DateTime? endTime;

	GetFacturyOrgByPageRequest({
		this.keyword,
		this.startTime,
		this.endTime,
		int pageIndex = 0,
		int pageSize = 0,
		String? token,
	}) : super(
			pageIndex: pageIndex,
			pageSize: pageSize,
			token: token,
		);

	factory GetFacturyOrgByPageRequest.fromJson(Map<String, dynamic> map) {
		return GetFacturyOrgByPageRequest( 
			keyword: map['Keyword'],
			startTime: map['StartTime'] != null ? DateTime.parse(map['StartTime']) : null,
			endTime: map['EndTime'] != null ? DateTime.parse(map['EndTime']) : null,
			pageIndex: map['PageIndex'],
			pageSize: map['PageSize'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (keyword != null)
			map['Keyword'] = keyword;
		if (startTime != null)
			map['StartTime'] = JsonRpcUtils.dateFormat(startTime!);
		if (endTime != null)
			map['EndTime'] = JsonRpcUtils.dateFormat(endTime!);
		return map;
	}
}

class GetFacturyUserByPageRequest extends PageRequest{
	String? facturyOrgCode;
	String? keyword;
	DateTime? startTime;
	DateTime? endTime;

	GetFacturyUserByPageRequest({
		this.facturyOrgCode,
		this.keyword,
		this.startTime,
		this.endTime,
		int pageIndex = 0,
		int pageSize = 0,
		String? token,
	}) : super(
			pageIndex: pageIndex,
			pageSize: pageSize,
			token: token,
		);

	factory GetFacturyUserByPageRequest.fromJson(Map<String, dynamic> map) {
		return GetFacturyUserByPageRequest( 
			facturyOrgCode: map['FacturyOrgCode'],
			keyword: map['Keyword'],
			startTime: map['StartTime'] != null ? DateTime.parse(map['StartTime']) : null,
			endTime: map['EndTime'] != null ? DateTime.parse(map['EndTime']) : null,
			pageIndex: map['PageIndex'],
			pageSize: map['PageSize'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (facturyOrgCode != null)
			map['FacturyOrgCode'] = facturyOrgCode;
		if (keyword != null)
			map['Keyword'] = keyword;
		if (startTime != null)
			map['StartTime'] = JsonRpcUtils.dateFormat(startTime!);
		if (endTime != null)
			map['EndTime'] = JsonRpcUtils.dateFormat(endTime!);
		return map;
	}
}

class GetFacturyUserInfosRequest extends TokenRequest{
	String? facturyOrgCode;

	GetFacturyUserInfosRequest({
		this.facturyOrgCode,
		String? token,
	}) : super(
			token: token,
		);

	factory GetFacturyUserInfosRequest.fromJson(Map<String, dynamic> map) {
		return GetFacturyUserInfosRequest( 
			facturyOrgCode: map['FacturyOrgCode'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (facturyOrgCode != null)
			map['FacturyOrgCode'] = facturyOrgCode;
		return map;
	}
}

class RemoveFacturyUserRequest extends TokenRequest{
	String? code;

	RemoveFacturyUserRequest({
		this.code,
		String? token,
	}) : super(
			token: token,
		);

	factory RemoveFacturyUserRequest.fromJson(Map<String, dynamic> map) {
		return RemoveFacturyUserRequest( 
			code: map['Code'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (code != null)
			map['Code'] = code;
		return map;
	}
}

class FacturyExamRegisterResult {
	String? status;
	String? erroMsg;
	String? phyId;
	String? patName;
	String? gender;
	String? patAge;
	String? phone;
	String? orgName;
	String? address;
	String? lisClu;
	String? phyDate;
	String? patientID;
	String? no;

	FacturyExamRegisterResult({
		this.status,
		this.erroMsg,
		this.phyId,
		this.patName,
		this.gender,
		this.patAge,
		this.phone,
		this.orgName,
		this.address,
		this.lisClu,
		this.phyDate,
		this.patientID,
		this.no,
	});

	factory FacturyExamRegisterResult.fromJson(Map<String, dynamic> map) {
		return FacturyExamRegisterResult( 
			status: map['Status'],
			erroMsg: map['ErroMsg'],
			phyId: map['PhyId'],
			patName: map['PatName'],
			gender: map['Gender'],
			patAge: map['PatAge'],
			phone: map['Phone'],
			orgName: map['OrgName'],
			address: map['Address'],
			lisClu: map['LisClu'],
			phyDate: map['PhyDate'],
			patientID: map['PatientID'],
			no: map['No'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = Map<String, dynamic>();
		if (status != null)
			map['Status'] = status;
		if (erroMsg != null)
			map['ErroMsg'] = erroMsg;
		if (phyId != null)
			map['PhyId'] = phyId;
		if (patName != null)
			map['PatName'] = patName;
		if (gender != null)
			map['Gender'] = gender;
		if (patAge != null)
			map['PatAge'] = patAge;
		if (phone != null)
			map['Phone'] = phone;
		if (orgName != null)
			map['OrgName'] = orgName;
		if (address != null)
			map['Address'] = address;
		if (lisClu != null)
			map['LisClu'] = lisClu;
		if (phyDate != null)
			map['PhyDate'] = phyDate;
		if (patientID != null)
			map['PatientID'] = patientID;
		if (no != null)
			map['No'] = no;
		return map;
	}
}

class FacturyExamRegisterRequest extends TokenRequest{
	String? identity;
	String? patientName;

	FacturyExamRegisterRequest({
		this.identity,
		this.patientName,
		String? token,
	}) : super(
			token: token,
		);

	factory FacturyExamRegisterRequest.fromJson(Map<String, dynamic> map) {
		return FacturyExamRegisterRequest( 
			identity: map['Identity'],
			patientName: map['PatientName'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (identity != null)
			map['Identity'] = identity;
		if (patientName != null)
			map['PatientName'] = patientName;
		return map;
	}
}

class FacturyExamDeleteResult {
	String? status;
	String? erroMsg;

	FacturyExamDeleteResult({
		this.status,
		this.erroMsg,
	});

	factory FacturyExamDeleteResult.fromJson(Map<String, dynamic> map) {
		return FacturyExamDeleteResult( 
			status: map['Status'],
			erroMsg: map['ErroMsg'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = Map<String, dynamic>();
		if (status != null)
			map['Status'] = status;
		if (erroMsg != null)
			map['ErroMsg'] = erroMsg;
		return map;
	}
}

class FacturyExamDeleteRequest extends TokenRequest{
	String? phyId;
	String? identity;
	String? patientName;

	FacturyExamDeleteRequest({
		this.phyId,
		this.identity,
		this.patientName,
		String? token,
	}) : super(
			token: token,
		);

	factory FacturyExamDeleteRequest.fromJson(Map<String, dynamic> map) {
		return FacturyExamDeleteRequest( 
			phyId: map['PhyId'],
			identity: map['Identity'],
			patientName: map['PatientName'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (phyId != null)
			map['PhyId'] = phyId;
		if (identity != null)
			map['Identity'] = identity;
		if (patientName != null)
			map['PatientName'] = patientName;
		return map;
	}
}


